@@ -1,8 +1,8 @@
-.onLoad <- function(library, section) {
-   require("methods")
-   require("TSdbi")
-   require("RSQLite")
-   }
+#.onLoad <- function(library, section) {
+#   require("methods")
+#   require("TSdbi")
+#   require("RSQLite")
+#   }
 
 setClass("TSSQLiteConnection", contains=c("SQLiteConnection","TSdb")) 
 
